[ "$DBUS_SESSION_BUS_ADDRESS" ] && return

DBUS_SESSION_BUS_SOCKET="$XDG_RUNTIME_DIR"/bus

[ -S "$DBUS_SESSION_BUS_SOCKET" ] || return

[ -L "$XDG_RUNTIME_DIR"/openrc/started/dbus ] || return

export DBUS_SESSION_BUS_ADDRESS="unix:path=$DBUS_SESSION_BUS_SOCKET"
